url = 'https://jira.jnj.com'
username = 'Enter JNJ user ID here'
password = 'Enter JNJ Password here'
test_case_key = ['Enter Jira Test case ID here']  # Example for multiple data ['ABCD-1234','ABCD-1234']
test_execution_key = 'Enter Jira Execution ID here'
