<p style="color: #2e6c80;"><h3><span style="color: #000000;">Evidence(s)</span></h3></p>

<h3> <span style="float:left;">Title : </span></h3>
<span style="padding-left:5px">{{ screenname }}</span>

<!--<h3> <span style="float:left;">Last Modification Time : </span></h3>-->
<!--<span style="padding-left:5px">{{ screenshottime }}</span>-->

<!--<p><img src= "{{ image }}"/></p>-->
<p><img src="data:image/jpeg;base64,{{ image }}"></p>
