<!DOCTYPE html>
<html>
<head>
    {% block head %}
    <title>Test Report | {% block title %}{% endblock %}</title>
    {% include 'style.html' %}
    {% endblock %}
</head>
<body style="background-color:#FAFFFD;">
    {% block body %}{% endblock %}
</body>
</html>