<style>
table {
  border-collapse: collapse;
  page-break-inside:avoid;
  page-break-after:auto;
  width: 100%;
}
td, th {
  border: 2px solid black;
  max-width: 1px;
  hyphens: auto;
}
th, td {
  padding-left: 10px;
}
tr    { page-break-inside:avoid; page-break-after:auto }
div {
    white-space: pre-wrap;
}
img{
    max-width:100%;
}
.footer {
  position: fixed;
  left: 0;
  bottom: 0;
  width: 100%;
  color: black;
  text-align: center;
  padding-top: 10px;
  padding-bottom: 1px;
  margin-top: 20px;
}
.content{

  word-wrap: break-word;
}
</style>