<h3>Step {{ stepcount }} :</h3>
    <table style="margin-bottom: 15px;">
    <tr align="center">
        <th style="text-align: center; padding: 6px;">Description</th>
        <th style="text-align: center; padding: 6px;">Expected Result</th>
        <th style="text-align: center; padding: 6px;">Actual</th>
        <th style="text-align: center; padding: 6px;">Status</th>
    </tr>
    <tr>
        <td width="20%" style="word-wrap: break-word;"><div>{{ TestStep }}</div></td>
        <td width="25%" style="word-wrap: break-word;"><div>{{ ExpectedResult }}</div></td>
        <td width="43%" style="word-wrap: break-word;"><div>{{ ActualResult }}</div></td>
        {% if teststatus.startswith("PASS") %}
            <td width="12%"><span style="font-size:100%; color: #00CC00;"><b>{{ teststatus }}</b></span></td>
        {% elif teststatus.startswith("FAIL") %}
            <td width="12%"><span style="font-size:100%; color: #ff0000;"><b>{{ teststatus }}</b></span></td>
        {% else %}
            <td width="12%"><span style="font-size:100%; color: #ff0000;"><b>{{ teststatus }}</b></span></td>
        {% endif %}
    </tr>
    </table>

<table style="width:100%">
  <colgroup>
       <col span="1" style="width: 40%;">
       <col span="1" style="width: 40%;">
       <col span="1" style="width: 20%;">
  </colgroup>
  <tbody>
<!--  <tr>-->
<!--    <th style="text-align: center; padding: 6px;">Step Start Time</th>-->
<!--    <th style="text-align: center; padding: 6px;">Step End Time</th>-->
<!--    <th style="text-align: center; padding: 6px;">Step Total Time</th>-->
<!--  </tr>-->
<!--  <tr>-->
<!--    <td>{{ stepstart }}</td>-->
<!--    <td>{{ stepend }}</td>-->
<!--    <td>{{ steptimediff }} seconds</td>-->
<!--  </tr>-->
</table>

<hr>



<!--<h3>Title :</h3>-->
<!--<span>{{ screenname }}</span>-->

<!--<h3>Last Modification Time :</h3>-->

<!--<p style="page-break-before: always">-->

