{% macro table_render(dict_data) -%}
<table>
    <tr align="center">
        <td width="25%"><h4> Variable Name </h4></td>
        <td width="75%"><h4> Variable Value </h4></td>
    </tr>
    {% for variable, value in dict_data.items() %}
        <tr>
            <td width="25%">{{ variable | safe}}</td>
            <td width="75%">{{ value | safe}}</td>
        </tr>
    {% endfor %}
</table>
{%- endmacro %}