{% macro render_table(start_time, end_time, total_time, table_type="Step") -%}
</br>
<table>
    <tr align="center">
        <td width="40%"><h4> {{table_type}} Start Time </h4></td>
        <td width="40%"><h4> {{table_type}} End Time </h4></td>
        <td width="20%"><h4> {{table_type}} Total time </h4></td>
    </tr>
    <tr>
        <td width="40%">{{ start_time | safe}}</td>
        <td width="40%">{{ end_time | safe}}</td>
        <td width="20%">{{ total_time | safe}}</td>
    </tr>
</table>
{%- endmacro %}